"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const CallTranscriber_1 = require("./CallTranscriber");
const events_1 = require("events");
class TranscriberTestDouble extends events_1.EventEmitter {
    close() {
        //Intentionally empty
    }
    transcribe() {
        //Intentionally empty
    }
    produceTranscriptionEvent(event) {
        this.emit("transcription", event);
    }
    transcriptionComplete() {
        //Intentionally empty
    }
}
describe("Call Transcriber", () => {
    const oneSecondInterval = 1000;
    let callTranscriber;
    let transcriberPlugin;
    beforeEach(() => {
        transcriberPlugin = new TranscriberTestDouble();
        const call = {
            sendDtmfTone: jest.fn(),
            sendMedia: jest.fn(),
            getStream: jest
                .fn()
                .mockReturnValue({ on: jest.fn().mockReturnValue({ on: jest.fn() }) }),
            close: jest.fn(),
            isOpen: jest.fn(),
            on: jest.fn(),
            off: jest.fn(),
            emit: jest.fn(),
        };
        callTranscriber = new CallTranscriber_1.CallTranscriber(call, transcriberPlugin, oneSecondInterval);
    });
    test("transcriber told transcription completed after final transcription", async () => {
        jest.spyOn(transcriberPlugin, "transcriptionComplete");
        transcriberPlugin.produceTranscriptionEvent({
            isFinal: true,
            transcription: "this is final.",
        });
        await new Promise((resolve) => {
            callTranscriber.on("transcription", resolve);
        });
        expect(transcriberPlugin.transcriptionComplete).toHaveBeenCalled();
    });
    test("final transcriptions are concatenated after X", async () => {
        transcriberPlugin.produceTranscriptionEvent({
            isFinal: true,
            transcription: "this is final.",
        });
        transcriberPlugin.produceTranscriptionEvent({
            isFinal: true,
            transcription: "this is final too",
        });
        const transcription = await new Promise((resolve) => {
            callTranscriber.on("transcription", resolve);
        });
        expect(transcription).toStrictEqual({
            isComplete: true,
            transcription: "this is final. this is final too",
        });
    });
    test("latest partial transcription returned after X", async () => {
        transcriberPlugin.produceTranscriptionEvent({
            isFinal: false,
            transcription: "first partial",
        });
        transcriberPlugin.produceTranscriptionEvent({
            isFinal: false,
            transcription: "second partial",
        });
        const transcription = await new Promise((resolve) => {
            callTranscriber.on("transcription", resolve);
        });
        expect(transcription).toStrictEqual({
            isComplete: true,
            transcription: "second partial",
        });
    });
    test("final transcription concatenated with latest partial transcription after X", async () => {
        transcriberPlugin.produceTranscriptionEvent({
            isFinal: true,
            transcription: "final sentence",
        });
        transcriberPlugin.produceTranscriptionEvent({
            isFinal: false,
            transcription: "latest partial",
        });
        const transcription = await new Promise((resolve) => {
            callTranscriber.on("transcription", resolve);
        });
        expect(transcription).toStrictEqual({
            isComplete: true,
            transcription: "final sentence latest partial",
        });
    });
});
