"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const CloseServerWhenTestsComplete_1 = require("./CloseServerWhenTestsComplete");
const Emitter_1 = require("../Emitter");
class StubCallServer extends Emitter_1.TypedEmitter {
    listen() {
        return Promise.resolve(undefined);
    }
    stop() {
        // Intentionally empty
    }
}
class StubTestInstance extends Emitter_1.TypedEmitter {
    getCall() {
        throw new Error("Not Implemented");
    }
    getTest() {
        throw new Error("Not Implemented");
    }
}
describe("Close server when tests complete", () => {
    let pluginEmitter;
    let callServer;
    beforeEach(() => {
        pluginEmitter = new Emitter_1.TypedEmitter();
        callServer = new StubCallServer();
    });
    test("closes server when all tests succeed", () => {
        const stopWhenAllTestsComplete = new CloseServerWhenTestsComplete_1.CloseServerWhenTestsComplete();
        stopWhenAllTestsComplete.initialise(pluginEmitter);
        pluginEmitter.emit("callServerStarted", {
            callServer: callServer,
        });
        const testInstance = new StubTestInstance();
        callServer.emit("testStarted", { testInstance });
        jest.spyOn(callServer, "stop");
        testInstance.emit("testPassed", { test: undefined });
        expect(callServer.stop).toHaveBeenCalled();
    });
    test("closes server when all tests fail", () => {
        const stopWhenAllTestsComplete = new CloseServerWhenTestsComplete_1.CloseServerWhenTestsComplete();
        stopWhenAllTestsComplete.initialise(pluginEmitter);
        pluginEmitter.emit("callServerStarted", {
            callServer: callServer,
        });
        const testInstance = new StubTestInstance();
        callServer.emit("testStarted", { testInstance });
        jest.spyOn(callServer, "stop");
        testInstance.emit("testFailed", {
            test: undefined,
            transcription: undefined,
        });
        expect(callServer.stop).toHaveBeenCalled();
    });
    test("server not closed if all tests are not complete", () => {
        const stopWhenAllTestsComplete = new CloseServerWhenTestsComplete_1.CloseServerWhenTestsComplete();
        stopWhenAllTestsComplete.initialise(pluginEmitter);
        pluginEmitter.emit("callServerStarted", {
            callServer: callServer,
        });
        const testInstance1 = new StubTestInstance();
        const testInstance2 = new StubTestInstance();
        callServer.emit("testStarted", { testInstance: testInstance1 });
        callServer.emit("testStarted", { testInstance: testInstance2 });
        jest.spyOn(callServer, "stop");
        testInstance1.emit("testPassed", { test: undefined });
        expect(callServer.stop).not.toHaveBeenCalled();
    });
});
