"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ws_1 = __importDefault(require("ws"));
const TwilioCallServer_1 = require("./TwilioCallServer");
const get_port_1 = __importDefault(require("get-port"));
const url_1 = require("url");
const wait_for_expect_1 = __importDefault(require("wait-for-expect"));
const TwilioCall_1 = require("../call/TwilioCall");
const waitForConnection = async (ws) => new Promise((resolve) => ws.on("open", resolve));
const fiveSeconds = 10 * 1000;
jest.setTimeout(fiveSeconds);
describe("Call Server", () => {
    let callServer;
    let callConnection;
    let testAssigner;
    let testExecutor;
    let dtmfGenerator;
    beforeEach(() => {
        testAssigner = {
            assign: jest.fn(),
        };
        testExecutor = { startTest: jest.fn() };
        dtmfGenerator = { generate: jest.fn() };
    });
    afterEach(async () => {
        console.group("Tidy Connections");
        if (callServer) {
            console.debug("Closing call server...");
            await callServer.stop();
            console.debug("Call server closed");
        }
        if (callConnection && callConnection.readyState !== ws_1.default.CLOSED) {
            console.debug("Waiting for call connection to close...");
            await new Promise((resolve) => callConnection.on("close", resolve));
            console.debug("Call connection closed");
        }
        console.groupEnd();
    });
    test("server's local websocket URL", async () => {
        callServer = new TwilioCallServer_1.TwilioCallServer(dtmfGenerator, testAssigner, testExecutor);
        const port = await get_port_1.default();
        const serverUrl = await callServer.listen(port);
        expect(serverUrl).toEqual(new url_1.URL(`ws://[::]:${port}/`));
    });
    test("call closed when call connected and no test assigned", async () => {
        testAssigner.assign.mockReturnValue({
            isAssigned: false,
            reason: "test reason",
        });
        callServer = new TwilioCallServer_1.TwilioCallServer(dtmfGenerator, testAssigner, testExecutor);
        const serverUrl = await callServer.listen(await get_port_1.default());
        callConnection = new ws_1.default(serverUrl);
        await waitForConnection(callConnection);
        await wait_for_expect_1.default(() => expect(callConnection.readyState).toBe(callConnection.CLOSED));
    });
    test("test assigned started when call connected", async () => {
        const test = { name: "example-test", test: undefined };
        testAssigner.assign.mockReturnValue({ isAssigned: true, test });
        callServer = new TwilioCallServer_1.TwilioCallServer(dtmfGenerator, testAssigner, testExecutor);
        const serverUrl = await callServer.listen(await get_port_1.default());
        callConnection = new ws_1.default(serverUrl);
        await waitForConnection(callConnection);
        await wait_for_expect_1.default(() => expect(testExecutor.startTest).toBeCalledWith(test, expect.any(TwilioCall_1.TwilioCall)));
    });
});
