import { AssertThen } from "./conditions/AssertThen";
import { CallTranscriptionEvents } from "../../call/transcription/CallTranscriber";
import { Call } from "../../call/Call";
import { Emitter, TypedEmitter } from "../../Emitter";
import { IvrTest } from "./IvrTest";
export interface TestResult {
    matchedCondition?: AssertThen;
    result: "continue" | "fail" | "pass";
}
export interface TestFailed {
    test: IvrTest;
    transcription: string;
}
export interface TestPassed {
    test: IvrTest;
}
export interface TestConditionMet {
    test: IvrTest;
    transcription: string;
    condition: AssertThen;
}
export interface TestProgressEvent {
    test: IvrTest;
    transcription: {
        isFinal: boolean;
        transcription: string;
    };
}
export declare type TestInstanceEvents = {
    testFailed: TestFailed;
    testPassed: TestPassed;
    conditionMet: TestConditionMet;
    progress: TestProgressEvent;
};
export interface TestInstance extends Emitter<TestInstanceEvents> {
    getTest(): IvrTest;
    getCall(): Call;
}
/**
 * Conditions have to have been met in sequence
 * @internal
 */
export declare class TestInstanceClass extends TypedEmitter<TestInstanceEvents> implements TestInstance {
    private readonly call;
    private readonly callTranscriber;
    private readonly ivrTest;
    constructor(call: Call, callTranscriber: Emitter<CallTranscriptionEvents>, ivrTest: IvrTest);
    getCall(): Call;
    private processTranscript;
    private notifyOfPassedTest;
    private notifyOfFailedTest;
    private notifyOfConditionBeingMet;
    getTest(): IvrTest;
}
