"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TestInstanceClass = void 0;
const Emitter_1 = require("../../Emitter");
/**
 * Conditions have to have been met in sequence
 * @internal
 */
// TODO Rename
class TestInstanceClass extends Emitter_1.TypedEmitter {
    constructor(call, callTranscriber, ivrTest) {
        super();
        this.call = call;
        this.callTranscriber = callTranscriber;
        this.ivrTest = ivrTest;
        callTranscriber.on("transcription", this.processTranscript.bind(this));
    }
    getCall() {
        return this.call;
    }
    processTranscript(event) {
        const { transcription } = event;
        this.emit("progress", {
            test: this.ivrTest,
            transcription: {
                isFinal: event.isComplete,
                transcription,
            },
        });
        if (!event.isComplete) {
            return;
        }
        const testOutcome = this.ivrTest.test.test(transcription, this.call);
        switch (testOutcome.result) {
            case "continue":
                if (testOutcome.matchedCondition) {
                    this.notifyOfConditionBeingMet(transcription, testOutcome.matchedCondition);
                }
                return;
            case "pass":
                if (testOutcome.matchedCondition) {
                    this.notifyOfConditionBeingMet(transcription, testOutcome.matchedCondition);
                }
                this.notifyOfPassedTest();
                return;
            case "fail":
                this.notifyOfFailedTest(transcription);
                return;
            default:
                return;
        }
    }
    notifyOfPassedTest() {
        const event = {
            test: this.ivrTest,
        };
        this.emit("testPassed", event);
    }
    notifyOfFailedTest(transcription) {
        const event = { transcription, test: this.ivrTest };
        this.emit("testFailed", event);
    }
    notifyOfConditionBeingMet(transcription, condition) {
        const event = {
            test: this.ivrTest,
            transcription,
            condition,
        };
        this.emit("conditionMet", event);
    }
    getTest() {
        return this.ivrTest;
    }
}
exports.TestInstanceClass = TestInstanceClass;
