"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const contains_1 = require("./contains");
describe("contains text", () => {
    test("can be configured to be case sensitive", () => {
        const transcript = "Hello World";
        expect(contains_1.contains("hello", { ignoreCasing: false })(transcript)).toBe(false);
        expect(contains_1.contains("Hello", { ignoreCasing: false })(transcript)).toBe(true);
    });
});
describe("contains multiple pieces of text", () => {
    test("passes if transcript contains all parts", () => {
        expect(contains_1.contains(["this", "test"])("this is a test")).toBe(true);
    });
    test("fails if transcript does not contain all parts", () => {
        expect(contains_1.contains(["this", "test"])("this is a")).toBe(false);
    });
});
describe("when", () => {
    test("when passed another when condition then each part of the transcript passed to it", () => {
        const mockWhen = jest.fn();
        contains_1.contains(mockWhen)("this is. a test");
        expect(mockWhen).toBeCalledWith("this");
        expect(mockWhen).toBeCalledWith("this is.");
        expect(mockWhen).toBeCalledWith("this is. a");
        expect(mockWhen).toBeCalledWith("this is. a test");
        expect(mockWhen).toBeCalledWith("is.");
        expect(mockWhen).toBeCalledWith("is. a");
        expect(mockWhen).toBeCalledWith("is. a test");
        expect(mockWhen).toBeCalledWith("a");
        expect(mockWhen).toBeCalledWith("a test");
        expect(mockWhen).toBeCalledWith("test");
        expect(mockWhen).toBeCalledTimes(10);
    });
    test("passes if the when argument returns true", () => {
        const mockWhen = jest.fn().mockReturnValue(true);
        expect(contains_1.contains(mockWhen)("this is a test")).toBe(true);
    });
    test("fails if the when argument returns false", () => {
        const mockWhen = jest.fn().mockReturnValue(false);
        expect(contains_1.contains(mockWhen)("this is a test")).toBe(false);
    });
});
