"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const inOrder_1 = require("./inOrder");
const when_1 = require("./conditions/when");
const then_1 = require("./conditions/then");
describe("ordered conditions", () => {
    let call;
    beforeEach(() => {
        call = {
            sendDtmfTone: jest.fn(),
            sendMedia: jest.fn(),
            getStream: jest.fn(),
            close: jest.fn(),
            isOpen: jest.fn(),
            on: jest.fn(),
            off: jest.fn(),
            emit: jest.fn(),
        };
    });
    test("test passes if no conditions provided", () => {
        const orderedConditions = inOrder_1.inOrder([]);
        const testOutcome = orderedConditions.test("Hello", call);
        expect(call.sendDtmfTone).not.toHaveBeenCalled();
        expect(testOutcome).toMatchObject({
            result: "pass",
        });
    });
    test("all match and test passes for last one", () => {
        const conditions = [
            {
                whenPrompt: when_1.contains("Hello"),
                then: then_1.press("1"),
            },
            {
                whenPrompt: when_1.contains("Jane"),
                then: then_1.press("2"),
            },
            {
                whenPrompt: when_1.contains("Austen"),
                then: then_1.press("3"),
            },
        ];
        const orderedConditions = inOrder_1.inOrder(conditions);
        const testOutcome1 = orderedConditions.test("Hello", call);
        expect(call.sendDtmfTone).toHaveBeenCalled();
        expect(testOutcome1).toMatchObject({
            matchedCondition: conditions[0],
            result: "continue",
        });
        const testOutcome2 = orderedConditions.test("Jane", call);
        expect(call.sendDtmfTone).toHaveBeenCalled();
        expect(testOutcome2).toMatchObject({
            matchedCondition: conditions[1],
            result: "continue",
        });
        const testOutcome3 = orderedConditions.test("Austen", call);
        expect(call.sendDtmfTone).toHaveBeenCalled();
        expect(testOutcome3).toMatchObject({
            matchedCondition: conditions[2],
            result: "pass",
        });
    });
    test("test failed when second condition doesn't match", () => {
        const conditions = [
            {
                whenPrompt: when_1.contains("Hello"),
                then: then_1.press("1"),
            },
            {
                whenPrompt: when_1.contains("Jane"),
                then: then_1.press("2"),
            },
        ];
        const orderedConditions = inOrder_1.inOrder(conditions);
        const testOutcome1 = orderedConditions.test("Hello", call);
        expect(call.sendDtmfTone).toHaveBeenCalled();
        expect(testOutcome1).toMatchObject({
            matchedCondition: conditions[0],
            result: "continue",
        });
        const testOutcome2 = orderedConditions.test("Darcy", call);
        expect(call.sendDtmfTone).toHaveBeenCalled();
        expect(testOutcome2).toMatchObject({
            result: "fail",
        });
    });
});
